
History
=======

1.2 (2017-03-01)
----------------

- Add dedicated CSS for ``plone5`` theme provided by ``yafowil.plone``.
  [rnix, 2016-06-28]

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix, 2016-06-28]


1.1 (2015-01-23)
----------------

- Update jquery UI slider to 1.10.3 and use latest jquery ui boostrap
  styles.
  [rnix, 2014-07-05]

1.0
---

- Make it work
  [rnix]
